package de.fraunhofer.iem.dataprovider.taskManager.tasks

import de.fraunhofer.iem.dataprovider.gitlab.GitlabConfiguration
import org.gitlab4j.api.GitLabApi

sealed class GetGitlabProjectTask(
    override val type: TaskType = TaskType.REPO_CHANGED,
    protected open val repoId: Any,
    private val gitlabConfiguration: GitlabConfiguration,
    private val responseChannel: suspend (task: ITask) -> Unit
): Task() {

    private val gitlabApi: GitLabApi = GitLabApi(gitlabConfiguration.host, gitlabConfiguration.accessToken)
    override suspend fun execute() {
        logger.info("Gitlab config ${gitlabConfiguration.host} ${gitlabConfiguration.accessToken}")
        val project = gitlabApi.projectApi.getProject(repoId)
        logger.info(project.toString())
        val projectUri = project.httpUrlToRepo
        val gitProject = GitProject(project.name, projectUri)
        logger.info("Retrieved project ${project.path} and url $projectUri")
        responseChannel(GitTask(this.type, gitProject, responseChannel))
    }
}

class GetGitlabProjectPathTask(
    override val repoId: String,
    private val gitlabConfiguration: GitlabConfiguration,
    private val responseChannel: suspend (task: ITask) -> Unit
): GetGitlabProjectTask(repoId = repoId, gitlabConfiguration = gitlabConfiguration, responseChannel = responseChannel )
class GetGitlabProjectIdTask(
    override val repoId: Long,
    private val gitlabConfiguration: GitlabConfiguration,
    private val responseChannel: suspend (task: ITask) -> Unit
): GetGitlabProjectTask(repoId = repoId, gitlabConfiguration = gitlabConfiguration, responseChannel = responseChannel )
